Class to store complex interactive heatmap objects from iheatmapr package
plotslist of plot element in IheatmapPlots format
shapeslist of shape element in IheatmapShapes format
annotationslist of annotation elements in
IheatmapAnnotations format
xaxeslist of x axes in IheatmapAxes format
yaxeslist of y axes in IheatmapAxes format
colorbarslist of colorbars in IheatmapColorbars format
colorbar_gridcolorbar grid parameters in
IheatmapColorbarGrid format
current_xaxisname of current x axis
current_yaxisname of current y axis
layoutlist of plotly layout parameters
sourcesource name, for use with shiny
Alicia Schep
This is a virtual class with two children classes,
IheatmapHorizontal and IheatmapVertical. For IheatmapHorizontal additional
main heatmaps are added horizontally, and for IheatmapVertical additional
main heatmaps are added vertically. For details on accessing certain slots
of this class, see access_component documentation.
iheatmap, main_heatmap,
access_component